<script src="{{ 'assets/pymdownx-extras/material-extra-theme-7c147bb7.js' | url }}" type="text/javascript"></script>
<script src="{{ 'assets/pymdownx-extras/material-extra-3rdparty-804b836e.js' | url }}" type="text/javascript"></script>
